@@ -74,12 +74,6 @@
 #include <QWebEngineNotification>
 #include <QWebEngineUrlScheme>
 
-#ifdef Q_OS_WIN
-#include <QtWin>
-#include <QWinJumpList>
-#include <QWinJumpListCategory>
-#endif
-
 #include <iostream>
 
 #if defined(Q_OS_WIN) && !defined(Q_OS_OS2)
@@ -121,6 +115,10 @@ MainApplication::MainApplication(int &argc, char** argv)
 
     setApplicationName(QStringLiteral("falkon"));
     setOrganizationDomain(QStringLiteral("org.kde"));
+#if defined(Q_OS_WIN)
+    QIcon::setFallbackThemeName(QStringLiteral("breeze"));
+    setStyle(QStringLiteral("breeze"));
+#endif
     setWindowIcon(QIcon::fromTheme(QSL("falkon"), QIcon(QSL(":icons/falkon.svg"))));
     setDesktopFileName(QSL("org.kde.falkon"));
 
@@ -240,6 +238,12 @@ MainApplication::MainApplication(int &argc, char** argv)
             appId.append(QSL(".TestMode"));
         }
 
+        /* Mark the appId with the current profile to allow subsequent commands to open tabs
+         * in a correct instance / window */
+        if (!startProfile.isEmpty() && (startProfile != QLatin1String("default"))) {
+            appId.append(QL1C('.') + startProfile);
+        }
+
         if (newInstance) {
             if (startProfile.isEmpty() || startProfile == QLatin1String("default")) {
                 std::cout << "New instance cannot be started with default profile!" << std::endl;
@@ -248,7 +252,7 @@ MainApplication::MainApplication(int &argc, char** argv)
                 // Generate unique appId so it is possible to start more separate instances
                 // of the same profile. It is dangerous to run more instances of the same profile,
                 // but if the user wants it, we should allow it.
-                appId.append(QLatin1Char('.') + startProfile + QString::number(QDateTime::currentMSecsSinceEpoch()));
+                appId.append(QString::number(QDateTime::currentMSecsSinceEpoch()));
             }
         }
 
@@ -416,9 +420,7 @@ void MainApplication::setChromiumFlags()
 
     if (Settings::globalSettings()->value("Web-Browser-Settings/hardwareAccel", false).toBool()) {
         chromium_flags.append(" --enable-oop-rasterization --enable-gpu-rasterization --enable-native-gpu-memory-buffers");
-#if QTWEBENGINECORE_VERSION >= QT_VERSION_CHECK(6, 9, 0)
-        chromium_flags.append(" --use-gl=angle");
-#else
+#if QTWEBENGINECORE_VERSION < QT_VERSION_CHECK(6, 9, 0)
         chromium_flags.append(" --use-gl=desktop");
 #endif
         qputenv("QTWEBENGINE_CHROMIUM_FLAGS", chromium_flags);
@@ -823,7 +825,6 @@ void MainApplication::postLaunch()
         getWindow()->toggleFullScreen();
     }
 
-    createJumpList();
     initPulseSupport();
 
     QTimer::singleShot(5000, this, &MainApplication::runDeferredPostLaunchActions);
@@ -1250,7 +1251,7 @@ void MainApplication::setUserStyleSheet(const QString &filePath)
     highlightColor = pal.color(QPalette::Highlight).name();
     highlightedTextColor = pal.color(QPalette::HighlightedText).name();
 #endif
-    userCss += QString("::selection {background: %1; color: %2;} ").arg(highlightColor, highlightedTextColor);
+    userCss += QStringLiteral("::selection {background: %1; color: %2;} ").arg(highlightColor, highlightedTextColor);
 #endif
 
     userCss += QzTools::readAllFileContents(filePath).remove(QLatin1Char('\n'));
@@ -1272,29 +1273,6 @@ void MainApplication::setUserStyleSheet(const QString &filePath)
     m_webProfile->scripts()->insert(script);
 }
 
-void MainApplication::createJumpList()
-{
-#ifdef Q_OS_WIN
-    QWinJumpList *jumpList = new QWinJumpList(this);
-    jumpList->clear();
-
-    // Frequent
-    QWinJumpListCategory *frequent = jumpList->frequent();
-    frequent->setVisible(true);
-    const QVector<HistoryEntry> mostList = m_history->mostVisited(7);
-    for (const HistoryEntry &entry : mostList) {
-        frequent->addLink(IconProvider::iconForUrl(entry.url), entry.title, applicationFilePath(), QStringList{(QString::fromUtf8entry.url.toEncoded())});
-    }
-
-    // Tasks
-    QWinJumpListCategory *tasks = jumpList->tasks();
-    tasks->setVisible(true);
-    tasks->addLink(IconProvider::newTabIcon(), tr("Open new tab"), applicationFilePath(), {QSL("--new-tab")});
-    tasks->addLink(IconProvider::newWindowIcon(), tr("Open new window"), applicationFilePath(), {QSL("--new-window")});
-    tasks->addLink(IconProvider::privateBrowsingIcon(), tr("Open new private window"), applicationFilePath(), {QSL("--private-browsing")});
-#endif
-}
-
 void MainApplication::initPulseSupport()
 {
     qputenv("PULSE_PROP_OVERRIDE_application.name", "Falkon");
