@@ -27,11 +27,11 @@ class BookmarkItem;
 class HtmlExporter : public BookmarksExporter
 {
 public:
-    explicit HtmlExporter(QObject* parent = 0);
+    explicit HtmlExporter(QObject* parent = nullptr);
 
-    QString name() const;
-    QString getPath(QWidget* parent);
-    bool exportBookmarks(BookmarkItem* root);
+    QString name() const override;
+    QString getPath(QWidget* parent) override;
+    bool exportBookmarks(BookmarkItem* root) override;
 
 private:
     void writeBookmark(BookmarkItem* item, QTextStream &stream, int level);
