@@ -24,11 +24,11 @@
 class FALKON_EXPORT DownIcon : public ClickableLabel
 {
 public:
-    explicit DownIcon(QWidget* parent = 0);
+    explicit DownIcon(QWidget* parent = nullptr);
 
 private:
-    void contextMenuEvent(QContextMenuEvent* ev);
-    void mousePressEvent(QMouseEvent* ev);
+    void contextMenuEvent(QContextMenuEvent* ev) override;
+    void mousePressEvent(QMouseEvent* ev) override;
 
 };
 
