@@ -25,7 +25,7 @@
 
 AutoScrollPlugin::AutoScrollPlugin()
     : QObject()
-    , m_scroller(0)
+    , m_scroller(nullptr)
 {
 }
 
@@ -49,7 +49,7 @@ void AutoScrollPlugin::unload()
 bool AutoScrollPlugin::testPlugin()
 {
     // Require the version that the plugin was built with
-    return (Qz::VERSION == QLatin1String(FALKON_VERSION));
+    return (QString::fromLatin1(Qz::VERSION) == QLatin1String(FALKON_VERSION));
 }
 
 void AutoScrollPlugin::showSettings(QWidget* parent)
